==> haskell-resource-pool-0.2.3.2-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-DxGOJlFiQFu2weH2nwR4Ol
key: resource-pool-0.2.3.2-DxGOJlFiQFu2weH2nwR4Ol
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Pool
abi: 0ce0b3fd6d85dc701f21497de92114cd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-DxGOJlFiQFu2weH2nwR4Ol
depends:
    base-4.10.1.0 hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J transformers-0.5.2.0
    transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2
    stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw time-1.8.0.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J=ce72e9c06e97f7bac790a30fd0148a82
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2=0446e63134f05bfe811d0020407f145f
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=63c518eabfb1b430d925fb35cc544a7c
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-JwLWIAEPuNiEkt6UPEV6jI
key: resource-pool-0.2.3.2-JwLWIAEPuNiEkt6UPEV6jI
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Pool
abi: 488b51a1fdef8ce63ad7e99365be1a4d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-JwLWIAEPuNiEkt6UPEV6jI
depends:
    base-4.10.1.0 hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv transformers-0.5.2.0
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x time-1.8.0.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             monad-control-1.0.2.2-Cf7Y7IL4PGG7qLiejghsYv=4ed72a305de1efe6a7bffe480e981599
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=34c1d6b33f33105a74600f465b68cb2b
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
